@@ -1,6 +1,6 @@
 #' Trace of a Matrix
 #'
-#' Calculates the trace of a numeric matrix, i.e., the sum of its diagonal elements
+#' Calculates the trace of a square numeric matrix, i.e., the sum of its diagonal elements
 #'
 #' @param X a numeric matrix
 #' @return a numeric value, the sum of \code{diag(X)}
@@ -9,6 +9,6 @@
 #' tr(X)
 #'
 tr <- function(X) {
-  if (!is.numeric(X) || !is.matrix(X)) stop("X must be a numeric matrix")
+  if (!is.numeric(X) || !is.matrix(X) || !nrow(X) == ncol(X)) stop("X must be a square numeric matrix")
   sum(diag(X))
 }
